CA01-Cl03
open | /admin/ |
type | id_username | admin
type | id_password | merengue
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=Añadir section |
type | id_name_es | CA01-Cl03 Section
type | id_slug | ca01-cl03-section
select | id_status | label=Publicado
clickAndWait | _addanother |
type | id_name_es | CA01-Cl03 Section
type | id_slug | ca01-cl03-section
select | id_status | label=Publicado
clickAndWait | _save |